searchNodes=[{"ref":"QuickStruct.html","title":"QuickStruct","type":"module","doc":"Creates a struct with enforced keys, the type of the struct and a make function to create the struct. You have to &quot;use&quot; this module and give a list of fields or a keyword list with fields and specs to create a struct. As an alternative you can create a module and a struct together; just require QuickStruct and call define_module/2. Examples Assume you define the following structs: defmodule QuickStructTest.User do use QuickStruct, [firstname: String.t, name: String.t] end defmodule QuickStructTest.Pair do use QuickStruct, [:first, :second] end Or equivalent: require QuickStruct QuickStruct.define_module QuickStructTest.User, [firstname: String.t, name: String.t] QuickStruct.define_module QuickStructTest.Pair, [:first, :second] To create a struct you can either use make/1 with a keyword list to specify the fields, or use make, where each argument is one field (order matters): iex&gt; alias QuickStructTest.User iex&gt; User.make(&quot;Jon&quot;, &quot;Adams&quot;) %User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;} iex&gt; User.make([name: &quot;Adams&quot;, firstname: &quot;Jon&quot;]) %User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;} iex&gt; alias QuickStructTest.Pair iex&gt; Pair.make(1, 0) %Pair{a: 1, b: 0} iex&gt; Pair.make([a: &quot;My&quot;, b: &quot;String&quot;]) %Pair{a: &quot;My&quot;, b: &quot;String&quot;}"},{"ref":"QuickStruct.html#constructor_with_defaults/1","title":"QuickStruct.constructor_with_defaults/1","type":"macro","doc":"Generates a function which will generate a struct with some given default values. Example defmodule Triple do use QuickStruct, [:first, :second, :third] QuickStruct.constructor_with_defaults([third: 0]) end pair = Triple.make_with_defaults([first: 24, second: 12]) # =&gt; %Triple{first: 24, second: 12, third: 0}"},{"ref":"QuickStruct.html#define_module/2","title":"QuickStruct.define_module/2","type":"macro","doc":"Defines a module together with a struct with the given field list. Example require QuickStruct QuickStruct.define_module(MyDate, [day: integer(), month: integer(), year: integer()]) new_year = %MyDate{day: 1, month: 1, year: 2000} This is equivalent to: defmodule MyDate do use QuickStruct, [day: integer(), month: integer(), year: integer()] end new_year = %MyDate{day: 1, month: 1, year: 2000}"},{"ref":"QuickStruct.html#is_struct_of/2","title":"QuickStruct.is_struct_of/2","type":"function","doc":"Returns true if the given object is a struct of the given module, otherwise false. Examples iex&gt; alias QuickStructTest.User iex&gt; QuickStruct.is_struct_of(%User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;}, QuickStructTest.User) true iex&gt; QuickStruct.is_struct_of(%User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;}, MyModule) false"},{"ref":"readme.html","title":"QuickStruct","type":"extras","doc":"QuickStruct Macro to create data structures as structs with less boilerplate."},{"ref":"readme.html#installation","title":"QuickStruct - Installation","type":"extras","doc":"First, add QuickStruct to your mix.exs dependencies: def deps do [{:quick_struct, &quot;~&gt; 0.1&quot;}] end and run $ mix deps.get."},{"ref":"readme.html#usage","title":"QuickStruct - Usage","type":"extras","doc":"defmodule User do use QuickStruct, [firstname: String.t, name: String.t] end Now you can use User.t in @type and @spec declarations. To create instances of your data structure, use one of the following options: iex(3)&gt; User.make(&quot;Jon&quot;, &quot;Adams&quot;) %User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;} iex(4)&gt; User.make([name: &quot;Adams&quot;, firstname: &quot;Jon&quot;]) %User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;} iex(5)&gt; %User{name: &quot;Adams&quot;, firstname: &quot;Jon&quot;} %User{firstname: &quot;Jon&quot;, name: &quot;Adams&quot;} You can also define a struct without types, for instance: defmodule QuickStructTest.Pair do use QuickStruct, [:first, :second] end Resulting code The QuickStruct macro is a very shorthand option to define a struct, a data type and enforce all fields. The User-struct is equivalent to: @enforce_keys [:firstname, :name] defstruct [:firstname, :name] @type t :: %User{firstname: String.t, name: String.t} The macro also provides make-functions as constructors and other functions, see QuickStruct for further documentation. The generated make-functions for the User-struct are equivalent to: @spec make(String.t, String.t) :: User.t def make(firstname, name) do %User{firstname: firstname, name: name} end @spec make([firstname: String.t, name: String.t]) :: User.t def make(fields) do Kernel.struct!(User, fields) end Creating modules and structs If you need plenty of different data structures, you can use require QuickStruct QuickStruct.define_module(User, [firstname: String.t, name: String.t]) QuickStruct.define_module(Pair, [:first, :second]) to create a module and the corresponding struct. So this is shorthand for: defmodule User do use QuickStruct, [firstname: String.t, name: String.t] end defmodule Pair do use QuickStruct, [:first, :second] end"},{"ref":"readme.html#license","title":"QuickStruct - License","type":"extras","doc":"Copyright © 2019 Active Group GmbH This work is free. You can redistribute it and/or modify it under the terms of the MIT License. See the LICENSE file for more details."}]